#include <Arduino.h>
#include <arduino_homekit_server.h>
#include "wifi_info.h"

#include <Wire.h>
#include <SPI.h>
#include <OneWire.h>
#include <DallasTemperature.h>

#ifdef ESP32
#pragma message(THIS EXAMPLE IS FOR ESP8266 ONLY!)
#error Select ESP8266 board.
#endif
unsigned int raw=0;
float batt=0.0;

#define ONE_WIRE_BUS 14
OneWire oneWire(ONE_WIRE_BUS);
DallasTemperature sensors(&oneWire);

#define LOG_D(fmt, ...)   printf_P(PSTR(fmt "\n") , ##__VA_ARGS__);


void setup() {
	Serial.begin(115200);
	wifi_connect(); // in wifi_info.h
  //homekit_storage_reset();
  sensors.begin(); // Start up the library
	my_homekit_setup();
    
}

void loop() {
	my_homekit_loop();
	delay(10);
}

//==============================
// Homekit setup and loop
//==============================

// access your homekit characteristics defined in my_accessory.c
extern "C" homekit_server_config_t config;
extern "C" homekit_characteristic_t cha_current_temperature;
//extern "C" homekit_characteristic_t cha_status_low_battery;

static uint32_t next_heap_millis = 0;
static uint32_t next_report_millis = 0;

void my_homekit_setup() {
	arduino_homekit_setup(&config);
}

void my_homekit_loop() {
	arduino_homekit_loop();
	const uint32_t t = millis();
	if (t > next_report_millis) {
		// report sensor values every 10 seconds
		next_report_millis = t + 10 * 1000;
		my_homekit_report();
	}
	if (t > next_heap_millis) {
		// show heap info every 5 seconds
		next_heap_millis = t + 5 * 1000;
		LOG_D("Free heap: %d, HomeKit clients: %d",
				ESP.getFreeHeap(), arduino_homekit_connected_clients_count());

	}
}

void my_homekit_report() {
  sensors.requestTemperatures();
	float temperature_value = sensors.getTempCByIndex(0); // FIXME, read your real sensor here.
	cha_current_temperature.value.float_value = temperature_value;
	LOG_D("Current temperature: %.1c", temperature_value);
	homekit_characteristic_notify(&cha_current_temperature, cha_current_temperature.value);
//   pinMode(A0, INPUT);
//  raw = analogRead(A0);
//  batt=raw/1023.0;
//  batt=batt*4.2;
//  float BATTERY_value = batt; // FIXME, read your real sensor here.
//  cha_status_low_battery.value.float_value = BATTERY_value;
//  LOG_D("Current STATUS_LOW_BATTERY: %.1c", BATTERY_value);
//  homekit_characteristic_notify(&cha_status_low_battery, cha_status_low_battery.value);
//  
}

int random_value(int min, int max) {
	return min + random(max - min);
}
